they

package
v0.12.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 13, 2023 License: BSD-3-Clause Imports: 2 Imported by: 0

Documentation

Overview

Package wants provides utilities learning what HTTP clients want.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Want

func Want(r *http.Request, method, pattern string) bool

A reports whether the request is for the given method and pattern. The provided pattern is automatically anchored at both ends.

It panics if the pattern is not a valid regular expression.

Types

This section is empty.

Jump to